# -*- coding: cp1252 -*-
"""Common filenames and locations for topographic data, meshes and outputs.
"""

from os import sep, environ, getenv, getcwd
from os.path import expanduser
import sys
from time import localtime, strftime, gmtime
from anuga.utilities.polygon import read_polygon, plot_polygons, polygon_area, is_inside_polygon

if sys.platform == 'win32':
    home = getenv('INUNDATIONHOME')
    user = getenv('USERPROFILE')

else:    
    home = getenv('INUNDATIONHOME', sep+'d'+sep+'xrd'+sep+'gem'+sep+'2'+sep+'ramp'+sep+'risk_assessment_methods_project'+sep+'inundation')     
    user = getenv('LOGNAME')
    print 'USER:', user

# INUNDATIONHOME is the inundation directory, not the data directory.
home += sep +'data'

#Making assumptions about the location of scenario data
state = 'new_south_wales'
scenario_dir_name = 'wollongong_tsunami_scenario_2006'

# onshore data provided by NSW LPI, Krishna merged with existing
# PMD data to make 100m DEM
on_offshore_name = '' 

# AHO
offshore_name1 = 'XY100011610'

#swollen/ all data output
basename = 'source'
codename = 'project_slide.py'

#Derive subdirectories and filenames
local_time = strftime('%Y%m%d_%H%M%S',gmtime()) 
meshdir = home+sep+state+sep+scenario_dir_name+sep+'anuga'+sep+'meshes'+sep
datadir = home+sep+state+sep+scenario_dir_name+sep+'anuga'+sep+'topographies'+sep
gaugedir = home+sep+state+sep+scenario_dir_name+sep+'anuga'+sep+'gauges'+sep
polygondir = home+sep+state+sep+scenario_dir_name+sep+'anuga'+sep+'polygons'+sep
boundarydir = home+sep+sep+state+sep+scenario_dir_name+sep+'anuga'+sep+'boundaries'+sep
outputdir = home+sep+state+sep+scenario_dir_name+sep+'anuga'+sep+'outputs'+sep
outputtimedir = outputdir + local_time + sep
polygondir = home+sep+state+sep+scenario_dir_name+sep+'anuga'+sep+'polygons'+sep

gauge_filename = gaugedir + 'gong_gauges.csv'
codedir = getcwd()+sep                            
codedirname = codedir + 'project_slide.py'
meshname = outputtimedir + 'mesh_' + basename

# Necessary if using point datasets, rather than grid
on_offshore_dem_name = datadir + on_offshore_name
offshore_dem_name1 = datadir + offshore_name1
combined_dem_name   = datadir + 'gong_combined_elevation'

###############################
# Domain definitions
###############################

# bounding polygon for study area
polyAll = read_polygon(polygondir+'extentA.csv')

print 'Area of bounding polygon', polygon_area(polyAll)/1000000.0

###############################
# Interior region definitions
###############################

# broome digitized polygons
poly_gong1 = read_polygon(polygondir+'.csv')
poly_gong2 = read_polygon(polygondir+'.csv')
poly_gong3 = read_polygon(polygondir+'.csv')

print 'Area of local polygon', polygon_area(poly_gong1)/1000000.0
print 'Area of close polygon', polygon_area(poly_gong2)/1000000.0
print 'Area of coastal polygon', polygon_area(poly_gong3)/1000000.0

###################################################################
# Clipping regions for export to asc and regions for clipping data
###################################################################

# exporting asc grid
eastingmin = 
eastingmax = 
northingmin = 
northingmax = 

###################################################################
# Slide characteristics
###################################################################

slide_origin_a = [352928.37,6188303.94]
slide_origin_b = [393301.80,6253255.08]
slide_origin_c = [446025.35,6330307.46]

bulli_depth = 2087.0
bulli_length = 16840.0
bulli_thickness = 424.0
bulli_width = 8860.0
bulli_density = 1.46
bulli_slope = 4.0
bulli_alpha = 126.0 + 90.0

shovel_depth = 968.0
shovel_length = 13500.0
shovel_thickness = 165.0
shovel_width = 4350.0
shovel_density = 1.49
shove_slope = 4.0
shovel_alpha = 118.0 + 90.0

yacaaba_depth = 1119.0
yacaaba_length = 7050.0
yacaaba_thickness = 144.0
yacaaba_width = 3080.0
yacaaba_density = 1.48
yacaaba_slope = 3.0
yacaaba_alpha = 133.0 + 90.0

